@@ -1,9 +1,15 @@
+import json
+
+
 def duck(value):
     if isinstance(value, str):
-        if value.isdigit():
+        if value.isdecimal():
             return int(value)
-        elif value.isdecimal():
+
+        try:
             return float(value)
+        except ValueError:
+            pass
     return value
 
 
@@ -16,3 +22,7 @@ def merge(src, dest):
             dest[key] = value
 
     return dest
+
+
+def pretty(data: dict):
+    return json.dumps(data, indent=4, sort_keys=True)
